@@ -31,7 +31,7 @@ class TimescaleClient:
         self.db_name = db_name
         self.standardized = standardized
         self.conn = psycopg2.connect(**kwargs)
-        if kwargs.get('PGPORT') == ["5000"]:
+        if kwargs.get('port') == "5000":
             read_only = False
         else:
             read_only = True
@@ -153,6 +153,13 @@ class TimescaleClientNarrow(TimescaleClient):
         pk = ['measurement_date', 'device_id', 'device_metric_type_id']
         TimescaleClient.__init__(self, db_name, pk, standardized, **kwargs)
 
+    @staticmethod
+    def get_agg_str(agg):
+        if agg == 'avg':
+            return "{0}(value)".format(agg)
+        else:
+            return "{0}(value, measurement_date)".format(agg)
+
     @staticmethod
     def standardize_df(df):
         """
@@ -192,28 +199,33 @@ class TimescaleClientNarrow(TimescaleClient):
     def get_aggregated_metrics(self, res, device_ids, metrics,
                                ts_start, ts_end, agg='avg', fill=None):
         self.allowed_agg(agg)
+
         if fill == 'locf':
-            # Last Observation Carried Forward
-            value_str = "locf({0}(value))".format(agg)
+            # Linear interpolation between points
+            value_str = "locf({0}) AS value".format(self.get_agg_str(agg))
         elif fill == 'interpolate':
             # Last Observation Carried Forward
-            value_str = "interpolate({0}(value))".format(agg)
+            value_str = "interpolate({0}) AS value"\
+                .format(self.get_agg_str(agg))
         else:
-            value_str = "{0}(value)".format(agg)
+            value_str = "{0} AS value".format(self.get_agg_str(agg))
         query = sql.SQL(
             "SELECT "
-            "time_bucket_gapfill({}, measurement_date) as measurement_date, "
-            "device_id, device_metric_type_id, %s"
+            "time_bucket_gapfill({}, measurement_date) as time, "
+            "device_id, device_metric_type_id, {} "
             "FROM {} "
             "WHERE device_id IN ({}) "
             "AND device_metric_type_id IN ({}) "
-            "AND measurement_date BETWEEN %s AND %s ") \
-            .format(sql.Literal(res), sql.Identifier(self.db_name),
+            "AND measurement_date BETWEEN %s AND %s "
+            "GROUP BY device_id, device_metric_type_id, time") \
+            .format(sql.Literal(res),
+                    sql.SQL(value_str),
+                    sql.Identifier(self.db_name),
                     sql.SQL(', ').join(sql.Placeholder() * len(device_ids)),
                     sql.SQL(', ').join(sql.Placeholder() * len(metrics)))
         df = self.query_to_df(query,
-                              [value_str] +
                               device_ids + metrics + [ts_start, ts_end])
+        df.rename(columns={'time': 'measurement_date'}, inplace=True)
         if self.standardized:
             return self.standardize_df(df)
         else:
@@ -345,7 +357,7 @@ class TimescaleClientJSON(TimescaleClient):
                                .format(self.get_agg_str(agg, m), m)
                                 for m in metrics])
         elif fill == 'interpolate':
-            # Last Observation Carried Forward
+            # Linear interpolation between points
             values = ", ".join(["interpolate({0}) AS \"{1}\""
                                .format(self.get_agg_str(agg, m), m)
                                 for m in metrics])
@@ -361,7 +373,7 @@ class TimescaleClientJSON(TimescaleClient):
             "FROM {} "
             "WHERE device_id IN ({}) "
             "AND measurement_date BETWEEN %s AND %s "
-            "GROUP BY time, device_id")\
+            "GROUP BY device_id, time")\
             .format(sql.Literal(res),
                     sql.SQL(values),
                     sql.Identifier(self.db_name),
